@@ -5,36 +5,40 @@
 (autoload 'custom-add-loads "cus-load")
 
 (custom-add-loads 'permanent-buffers '("permanent-buffers"))
-(custom-add-loads 'extensions '("iswitchb" "page-ext" "tempo"))
+(custom-add-loads 'extensions '("ido" "iswitchb" "page-ext" "tempo"))
 (custom-add-loads 'auto-revert '("autorevert"))
+(custom-add-loads 'buffer-colors '("buffer-colors"))
 (custom-add-loads 'recent-files-menu '("recent-files"))
 (custom-add-loads 'mouse '("avoid" "id-select" "outl-mouse"))
-(custom-add-loads 'convenience '("dabbrev" "power-macros"))
+(custom-add-loads 'register-menu '("register-menu"))
+(custom-add-loads 'convenience '("dabbrev" "ido" "power-macros"))
 (custom-add-loads 'menu '("recent-files"))
 (custom-add-loads 'minibuffer '("detached-minibuf" "icomplete" "savehist"))
 (custom-add-loads 'environment '("popper"))
 (custom-add-loads 'allout '("allout"))
 (custom-add-loads 'man '("man"))
 (custom-add-loads 'completion '("completion"))
-(custom-add-loads 'tools '("func-menu" "lazy-shot"))
+(custom-add-loads 'tools '("func-menu" "lazy-shot" "which-func"))
 (custom-add-loads 'uniquify '("uniquify"))
 (custom-add-loads 'recent-files '("recent-files"))
 (custom-add-loads 'dabbrev '("dabbrev"))
+(custom-add-loads 'ido '("ido"))
 (custom-add-loads 'save-place '("saveplace"))
 (custom-add-loads 'lisp '("func-menu"))
 (custom-add-loads 'applications '("uniquify"))
 (custom-add-loads 'outlines '("allout" "outl-mouse"))
-(custom-add-loads 'paren-matching '("paren" "mic-paren"))
+(custom-add-loads 'paren-matching '("mic-paren" "paren"))
 (custom-add-loads 'avoid '("avoid"))
 (custom-add-loads 'help '("info-look" "man"))
 (custom-add-loads 'mic-paren-matching '("mic-paren" "paren"))
 (custom-add-loads 'winring '("winring"))
 (custom-add-loads 'data '("saveplace"))
+(custom-add-loads 'which-func '("which-func"))
 (custom-add-loads 'backup '("backup-dir"))
 (custom-add-loads 'id-select '("id-select"))
 (custom-add-loads 'outl-mouse '("outl-mouse"))
 (custom-add-loads 'lazy-lock '("lazy-lock"))
-(custom-add-loads 'frames '("balloon-help" "desktop" "detached-minibuf" "rsz-minibuf" "winring"))
+(custom-add-loads 'frames '("balloon-help" "desktop" "detached-minibuf" "highline" "rsz-minibuf" "winring"))
 (custom-add-loads 'edit-toolbar '("toolbar-utils"))
 (custom-add-loads 'bookmarks '("bookmark"))
 (custom-add-loads 'desktop '("desktop"))
@@ -45,23 +49,26 @@
 (custom-add-loads 'fume '("func-menu"))
 (custom-add-loads 'blink-cursor '("blink-cursor"))
 (custom-add-loads 'power-macros '("power-macros"))
+(custom-add-loads 'find-file '("find-file"))
 (custom-add-loads 'files '("after-save-commands" "autorevert" "recent-files" "where-was-i-db"))
 (custom-add-loads 'fast-lock '("fast-lock"))
 (custom-add-loads 'font-lock '("lazy-lock"))
 (custom-add-loads 'where-was-i '("where-was-i-db"))
 (custom-add-loads 'popper '("popper"))
 (custom-add-loads 'tempo '("tempo"))
+(custom-add-loads 'highline '("highline"))
 (custom-add-loads 'detached-minibuf '("detached-minibuf"))
 (custom-add-loads 'resize-minibuffer '("rsz-minibuf"))
 (custom-add-loads 'info-lookup '("info-look"))
 (custom-add-loads 'languages '("info-look"))
 (custom-add-loads 'fill '("align"))
 (custom-add-loads 'balloon-help '("balloon-help"))
-(custom-add-loads 'faces '("fast-lock" "lazy-shot" "mic-paren"))
+(custom-add-loads 'faces '("fast-lock" "highline" "lazy-shot" "mic-paren"))
 (custom-add-loads 'pages '("page-ext"))
 (custom-add-loads 'savehist '("savehist"))
+(custom-add-loads 'ff '("find-file"))
 (custom-add-loads 'align '("align"))
-(custom-add-loads 'editing '("bookmark" "permanent-buffers"))
+(custom-add-loads 'editing '("bookmark" "highline" "permanent-buffers"))
 (custom-add-loads 'matching '("paren" "completion" "id-select"))
 (custom-add-loads 'c '("func-menu"))
 
